@@ -44,3 +44,26 @@ test_that("read things that are written to disc are the same as origs", {
   }
   
 })
+
+test_that("files containing utf-8 symbols in file names work (was an issue under windows)", {
+  
+  altDir = tempdir()
+  
+  wavFiles <- list.files(system.file("extdata", package = "wrassp"), pattern = glob2rx("*.wav"), full.names = TRUE)
+  
+  utf8filePath = enc2utf8(file.path(tempdir(), "bål.wav"))
+  file.copy(wavFiles[1], utf8filePath)
+  # check that reading works
+  ado = read.AsspDataObj(utf8filePath)
+  expect_equal(attr(ado, "sampleRate"), 16000)
+  # is encoding of filePath preserved?
+  expect_equal(Encoding(attr(ado, "filePath")), "UTF-8")
+  # check that writing works
+  write.AsspDataObj(ado, paste0(utf8filePath, "_new"))
+  expect_true(file.exists(paste0(utf8filePath, "_new")))
+  # function work 
+  zcrana(listOfFiles = utf8filePath)
+  expect_true(file.exists(paste0(tools::file_path_sans_ext(utf8filePath), ".zcr")))
+  unlink(utf8filePath)
+  unlink(paste0(utf8filePath, "_new"))
+})
\ No newline at end of file
